@@ -43,6 +43,11 @@ class AliCs:
 
     @classmethod
     def get_k8s_list(cls, params=None):
+        max_len = 50
+        if isinstance(params, dict):
+            params['PageSize'] = params.get('PageSize', max_len)
+        else:
+            params = {'PageSize': max_len}
         return cs_client.describe_clusters(params)
 
     @classmethod
