@@ -21,3 +21,9 @@ class AliRKvstore:
     @classmethod
     def get_security_ips(cls, params=None):
         return rkv_client.describe_security_ips(params)
+
+    @classmethod
+    def get_instance_auto_renewal_attribute(cls, params=None):
+        return rkv_client.describe_instance_auto_renewal_attribute(params)
+
+
